import json
import pulumi
import pulumi_aws
from typing import List
from theia.aws.security.iam import Role, InlinePolicy
from pydantic.dataclasses import dataclass, ConfigDict

class TaskDefinition:
    def __init__(self,
            cpu: int=None,
            resource_name:str= None,
            memory:int=None,
            network_mode:str="awsvpc",
            region:str = "us-east-1",
            requires_compatibilities: List[str] = ["FARGATE"],
            exec_role_arn: pulumi_aws.iam.Role.arn = None,
            load_balancer: pulumi_aws.lb.LoadBalancer = None,
            target_group: pulumi_aws.lb.TargetGroup = None,
            subnet_ids: List[str]= None
        ) -> None:
        
        self.task_definition = pulumi_aws.ecs.TaskDefinition(f"{resource_name}-taskdefinition",
            family=f"{resource_name}-taskfamily",
            cpu=str(cpu),
            memory=str(memory),
            network_mode=network_mode,
            requires_compatibilities=requires_compatibilities,
            execution_role_arn=exec_role_arn,
            container_definitions=pulumi.Output.all(load_balancer.arn, target_group.arn, subnet_ids).apply(lambda args: json.dumps(
            [
                {
                    "name": f"{resource_name}-container",
                    "image": f"{resource_name}-container-image:latest",
                    "portMappings": [
                        {
                            "containerPort": 80,
                            "protocol": "tcp"
                        }
                    ],
                    "logConfiguration": {
                        "logDriver": "awslogs",
                        "options": {
                            "awslogs-group": f"{resource_name}-log-group",
                            "awslogs-region": f"{region}",
                            "awslogs-stream-prefix": f"{resource_name}-container"
                        }
                    }
                }
            ])
            )
        )