import pulumi

from pulumi.output import Output
from pulumi_aws import LoadBalancer

from typing import Optional, List, Mapping
from pydantic.dataclasses import dataclass, ConfigDict
from theia import ResourceOptions
from theia.utils.logger import Logger
from theia._registry import StackRegistry
from theia.definitions import THEIA_VERSION
from theia.utils.errors import TheiaConfigurationError


logger = Logger("application loadbalancer")

@dataclass
class AlbSettings:
    access_logs: Optional[dict] = None,
    customer_owned_ipv4_pool: Optional[str] = None,
    desync_mitigation_mode: Optional[str] = None,
    drop_invalid_header_fields: Optional[bool] = None,
    enable_cross_zone_load_balancing: Optional[bool] = None,
    enable_deletion_protection: Optional[bool] = None,
    enable_http2: Optional[bool] = None,
    enable_tls_version_and_cipher_suite_headers: Optional[bool] = None,
    enable_waf_fail_open: Optional[bool] = None,
    enable_xff_client_port: Optional[bool] = None,
    idle_timeout: Optional[int] = None,
    internal: Optional[bool] = None,
    ip_address_type: Optional[str] = None,
    load_balancer_type: Optional[str] = None,
    name_prefix: Optional[str] = None,
    preserve_host_header: Optional[bool] = None,
    security_groups: Optional[List[str]] = None,
    subnet_mappings: Optional[List[dict]] = None,
    subnets: Optional[List[str]] = None,
    xff_header_processing_mode: Optional[str] = None

class LoadBalancer(pulumi.ComponentResource):
    def __init__(
        self,
        resource_name: str,
        alb_settings: Optional[AlbSettings]=AlbSettings(),
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> None:
        super().__init__("theia:aws:network", resource_name, None, opts)
        merged_tags = THEIA_VERSION
        name = {"Name": resource_name}
        if tags:
            merged_tags = {**tags, **name, **merged_tags}
        else:
            merged_tags = {**name, **merged_tags}

        depends = []
        logger.info(f"creating {alb_settings.load_balancer_type} Loadbalancer resource {resource_name}")
        lb_args=LoadBalancer.LoadBalancerArgs(
            access_logs=alb_settings.access_logs,
            customer_owned_ipv4_pool: Optional[str] = None,
            desync_mitigation_mode: Optional[str] = None,
            drop_invalid_header_fields: Optional[bool] = None,
            enable_cross_zone_load_balancing: Optional[bool] = None,
            enable_deletion_protection: Optional[bool] = None,
            enable_http2: Optional[bool] = None,
            enable_tls_version_and_cipher_suite_headers: Optional[bool] = None,
            enable_waf_fail_open: Optional[bool] = None,
            enable_xff_client_port: Optional[bool] = None,
            idle_timeout: Optional[int] = None,
            internal: Optional[bool] = None,
            ip_address_type: Optional[str] = None,
            load_balancer_type: Optional[str] = None,
            name_prefix: Optional[str] = None,
            preserve_host_header: Optional[bool] = None,
            security_groups: Optional[List[str]] = None,
            subnet_mappings: Optional[List[dict]] = None,
            subnets: Optional[List[str]] = None,
            xff_header_processing_mode: Optional[str] = None,
            name=resource_name,
        )