import pulumi

from pulumi_aws import ec2
from pulumi.output import Output

from typing import Optional, Mapping

from theia import ResourceOptions
from theia.definitions import THEIA_VERSION
from theia._registry import StackRegistry, GlobalTags


class InternetGateway:
    def __new__(
        cls,
        resource_name: str,
        vpc_id: str | Output[str],
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> ec2.InternetGateway:
        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | GlobalTags.get() | name
        if tags:
            merged_tags = tags | merged_tags

        igw = ec2.InternetGateway(
            resource_name, tags=merged_tags, vpc_id=vpc_id, opts=opts
        )

        pulumi.export(
            f"internet_gateway---{resource_name}", {"id": igw.id, "arn": igw.arn}
        )

        return igw

    @staticmethod
    def import_(stack: str, resource_name: str) -> ec2.InternetGateway:
        stack_ref = StackRegistry.get(stack_name=stack)
        igw = stack_ref.get_output(name=f"internet_gateway---{resource_name}")
        return ec2.InternetGateway.get(resource_name=resource_name, id=igw["id"])
