import pulumi

from typing import Mapping, Optional
from pulumi_aws import secretsmanager

from theia import ResourceOptions
from theia.definitions import THEIA_VERSION


class SecretManager:
    def __new__(
        cls,
        resource_name: str,
        description: Optional[str] = None,
        policy: Optional[str] = None,
        kms_key_id: Optional[str] = None,
        recovery_window_in_days: Optional[int] = 30,
        secret_content: Optional[str] = None,
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> secretsmanager.Secret:
        merged_tags = THEIA_VERSION
        name = {"Name": resource_name}
        if tags:
            merged_tags = {**tags, **name, **merged_tags}

        secret = secretsmanager.Secret(
            resource_name,
            name=resource_name,
            description=description,
            policy=policy,
            recovery_window_in_days=recovery_window_in_days,
            kms_key_id=kms_key_id,
            tags=tags,
            opts=opts,
        )

        if secret_content:
            _ = secretsmanager.SecretVersion(
                f"{resource_name}-secret",
                secret_id=secret.id,
                secret_string=secret_content,
                opts=ResourceOptions(parent=secret, depends_on=[secret]),
            )

        pulumi.export(f"secret---{resource_name}", {"id": secret.id, "arn": secret.arn})
        cls.secret_id = secret.id
        return secret

    @classmethod
    def new_secret(cls, name: str, content: str) -> secretsmanager.SecretVersion:
        return secretsmanager.SecretVersion(
            resource_name=name, secret_id=cls.secret_id, secret_string=content
        )
